package com.baidu.dueros.bot;/*
 * Copyright (c) 2017 Baidu, Inc. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import com.baidu.dueros.bot.BaseBot;
import com.baidu.dueros.data.request.IntentRequest;
import com.baidu.dueros.data.request.LaunchRequest;
import com.baidu.dueros.data.request.SessionEndedRequest;
import com.baidu.dueros.data.response.OutputSpeech;
import com.baidu.dueros.data.response.OutputSpeech.SpeechType;
import com.baidu.dueros.data.response.Reprompt;
import com.baidu.dueros.data.response.card.TextCard;
import com.baidu.dueros.model.Response;

import javax.servlet.http.HttpServletRequest;
import java.io.IOException;

/**
 * 查询个税Bot例子，继承{@code BaseBot}类
 * 
 * @author tianlonglong(tianlong02@baidu.com)
 * @version V1.0
 * @since 2017年10月5日
 */
public class Bot extends BaseBot {

    /**
     * 重写BaseBot构造方法
     * 
     * @param request
     *            servlet Request作为参数
     * @throws IOException
     *             抛出异常
     */
    public Bot(HttpServletRequest request) throws IOException {
        super(request);
    }

    /**
     * 重写BaseBot构造方法
     * 
     * @param request
     *            Request字符串
     * @throws IOException
     *             抛出异常
     */
    public Bot(String request) throws IOException {
        super(request);
    }

    /**
     * 重写onLaunch方法，处理onLaunch对话事件
     * 
     * @param launchRequest
     *            LaunchRequest请求体
     * @see BaseBot#onLaunch(LaunchRequest)
     */
    @Override
    protected Response onLaunch(LaunchRequest launchRequest) {
        // 新建文本卡片
        TextCard textCard = new TextCard("欢迎使用查询个税");
        // 设置链接地址
        textCard.setUrl("www:....");
        // 设置链接内容
        textCard.setAnchorText("setAnchorText");
        // 添加引导话术
        textCard.addCueWord("我想查询个税");
        // 新建返回的语音内容
        OutputSpeech outputSpeech = new OutputSpeech(SpeechType.PlainText, "欢迎使用查询个税");
        // 构造返回的Response
        Response response = new Response(outputSpeech, textCard);
        return response;
    }

    /**
     * 重写onInent方法，处理onInent对话事件
     *
     * @param intentRequest
     *            IntentRequest请求体
     * @see BaseBot#onInent(IntentRequest)
     */
    @Override
    protected Response onInent(IntentRequest intentRequest) {
        // 判断NLU解析的意图名称是否匹配 inquiry_tax
        if ("inquiry_tax".equals(intentRequest.getIntentName())) {
            // 判断NLU解析解析后是否存在这个槽位
            if (getSlot("sys.number") == null) {
                // 询问月薪槽位
                ask("sys.number");
                return askNumber();
            } else if (getSlot("sys.city") == null) {
                // 询问城市槽位
                ask("sys.city");
                return askCity();
            } else {
                // 计算个税缴纳情况
                return compute();
            }
        }

        return null;
    }

    /**
     * 重写onSessionEnded事件，处理onSessionEnded对话事件
     *
     * @param sessionEndedRequest
     *            SessionEndedRequest请求体
     * @see BaseBot#onSessionEnded(SessionEndedRequest)
     */
    @Override
    protected Response onSessionEnded(SessionEndedRequest sessionEndedRequest) {

        // 构造TextCard
        TextCard textCard = new TextCard("感谢您使用查询个税服务");
        textCard.setAnchorText("setAnchorText");
        textCard.addCueWord("");

        // 构造OutputSpeech
        OutputSpeech outputSpeech = new OutputSpeech(SpeechType.PlainText, "感谢您使用查询个税服务");

        // 构造Response
        Response response = new Response(outputSpeech, textCard);

        return response;
    }

    /**
     * 询问城市信息
     * 
     * @return Response 返回Response
     */
    private Response askCity() {

        TextCard textCard = new TextCard("您所在的城市是哪里呢?");
        textCard.setUrl("www:......");
        textCard.setAnchorText("setAnchorText");
        textCard.addCueWord("我在上海");

        OutputSpeech outputSpeech = new OutputSpeech(SpeechType.PlainText, "您所在的城市是哪里呢?");

        Reprompt reprompt = new Reprompt(outputSpeech);

        Response response = new Response(outputSpeech, textCard, reprompt);

        return response;
    }

    /**
     * 询问月薪
     * 
     * @return Response 返回Response
     */
    private Response askNumber() {

        TextCard textCard = new TextCard("您的税前工资是多少呢?");
        textCard.setUrl("www:......");
        textCard.setAnchorText("链接文本");
        textCard.addCueWord("我工资9000元");

  
        OutputSpeech outputSpeech = new OutputSpeech(SpeechType.PlainText, "您的税前工资是多少呢?");

        // 构造reprompt
        Reprompt reprompt = new Reprompt(outputSpeech);

        Response response = new Response(outputSpeech, textCard, reprompt);

        return response;
    }

    /**
     * 计算个税
     * 
     * @return Response
     */
    private Response compute() {

        String ret = "您需要缴纳税款167.40元，缴纳社保及公积金1776元，税后工资是6056.60元" ;

        TextCard textCard = new TextCard(ret);
        textCard.setAnchorText("setAnchorText");
        textCard.addCueWord("查询完成，欢迎您再次使用");

       
        OutputSpeech outputSpeech = new OutputSpeech(SpeechType.PlainText, ret);

        Reprompt reprompt = new Reprompt(outputSpeech);

        // 主动结束会话
        this.endDialog();

        Response response = new Response(outputSpeech, textCard, reprompt);

        return response;
    }
}
